| Title: | Plot Contour Line |
|---|---|
| Description: | This function plots a contour line with a user-defined probability and tightness of fit. |
| Authors: | Olivia Cheronet |
| Maintainer: | Olivia Cheronet <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-05-16 06:22:55 UTC |
| Source: | https://github.com/cran/PlotContour |
This function plots a contour line with a user-defined probability and tightness of fit on an existing plot.
PlotContour(Data, Probability, BandWidthX,BandWidthY,Colour)PlotContour(Data, Probability, BandWidthX,BandWidthY,Colour)
Data |
An n by 2 matrix of data points around which the contour will be drawn. |
Probability |
The proportion of points which should be within the contour line drawn. |
BandWidthX |
The tightness of fit of the contour line along the x-axis. This value will be proportional to the scale of the axis. |
BandWidthY |
The tightness of fit of the contour line along the y-axis. This value will be proportional to the scale of the axis. |
Colour |
Colour of the line to be drawn. |
Olivia Cheronet
#Plot a regular scatter plot plot(iris$Sepal.Length,iris$Sepal.Width) #Plot a contour line encompassing 75% of the points PlotContour(iris[,1:2],0.75,0.5,0.25,"red")#Plot a regular scatter plot plot(iris$Sepal.Length,iris$Sepal.Width) #Plot a contour line encompassing 75% of the points PlotContour(iris[,1:2],0.75,0.5,0.25,"red")